package interfacesFerrovia;

public interface DefsGlobais {
/**
 * Definies globais (enumeraes, constantes, etc.	
 * @author Fernando Vanini
 *
 */
	
	/**
	 *  Define os tipos de elementos da malha ferroviaria.
	 */
	public enum TipoElemento { COMPOSICAO, TRECHO, SENSOR, CHAVE }
	
	/**
	 *  Define os tipos possveis de falhas. 
	 */
	public enum TipoFalha { ELETRICA, MECANICA, FREIO, ACELERACAO, GERAL, INDEFINIDA }
	
	
	/**
	 * Define os atributos para cada um dos elementos da rede.
	 * Convenes para os valores dos atributos:
	 *     - tempos: inteiros, representando segundos.
	 *     - distancia: float, representando metros.
	 *     - velocidade: float, representanto m/s 
	 *     - acelerao e frenagem : float, representanto m/s/s (cada uma sempre >= 0)
	 *     
	 * Convenes para sentido da velocidade (trecho e chave):
	 * 		- velocidade > 0  ==>  sentido A->B
	 *      - velocidade < 0  ==>  sentido B->A
	 * 	
	 * Convenes para os trechos e composies
	 *     - posio da composio: 
	 *     		- extremidade A do trecho --> posio == 0
	 *     		- extremidade B do trecho --> posio >= distncia do trecho
	 */
	public enum TipoAtributo{
		// atributos fixos, comuns a todos os elementos 
		ID,   // identificao de um elemento da malha ferroviaria              [ Valor: String  ]
		TIPO, // tipo do elemento                                               [ Valor: TipoElemento ]
		
		// atributos especficos de uma composio
		// -- fixos --
		COMPRIMENTO,       // comprimento da composio.                        [ Valor: Integer  ]
		VELOCIDADE_MAX,    // velocidade mxima da composio                   [ Valor: Float    ]
		ACELERACAO_MAX,    // acelerao mxima.                                [ Valor: Float    ]
		FRENAGEM_MAX,      // frenagem mxima.                                  [ Valor: Float    ]
		ITINERARIO,        // itinerrio.                                       [ Valor: String[] ]
		PARTIDA,           // instante da partida (inicio da viagem)            [ Valor: Integer  ]
		// -- variveis ---
		ID_TR_CH_ATUAL,    // id. do trecho ou chave atual.                     [ Valor: String  ]
		POSICAO_ATUAL,     // posio atual (num trecho).                       [ Valor: Float   ]
		VEL_ATUAL,         // velocidade atual.                                 [ Valor: Float   ]
		SENTIDO_ATUAL,     // sentido (AB=>true, BA => false)                   [ Valor: Boolean ]
		ACEL_ATUAL,        // acelerao atual.                                 [ Valor: Float   ]
		FREN_ATUAL,        // taxa de frenagem atual.                           [ Valor: Float   ]
		EM_MOVIMENTO,      // true => composio em movimento.                  [ Valor: Boolean ]
		
		// atributos especficos de um trecho
        // -- fixos --		
		DISTANCIA,         // Distncia entre as extremidades                   [ Valor: Float   ]
		ID_TR_CH_A,        // identificao da chave conectada  extremidade A  [ Valor: String  ]
		ID_TR_CH_B,        // identificao da chave conectada  extremidade B  [ Valor: String  ]
		// N_SENSORES,     // nmero de sensores do trecho (eliminado 31/03)    [ Valor: Integer ]
		// -- variaveis --
		N_COMPOSICOES,     // nmero de composies trafegando pelo trecho      [ Valor: Integer ]
		
		// atributos especficos de uma chave
		// -- fixos --
		TRECHOS_A,         // trechos conectveis  extremidade A.              [ Valor: String[] ]
		TRECHOS_B,         // trechos conectveis  extremidade B.              [ Valor: String[] ]
		TEMPO_MUDANCA,     // tempo de mudana de estado.                       [ Valor: Integer  ]
		// DISTANCIA,      // herdado de Trecho                                 [ Valor: Integer  ]
		//TEMPO_PASSAGEM,  // tempo de passagem pela chave  (eliminado)         [ Valor: Float    ]
		// -- variaveis --
		EM_MUDANCA,        // true => em mudana de estado.                     [ Valor: Boolean  ]
		//TR_ATUAL_A,      // trecho atual na extremidade A (herda de Trecho)   [ Valor: String   ]
		//TR_ATUAL_B,      // trecho atual na extremidade B (herda de Trecho)   [ Valor: String   ]
		TEMPO_CONCLUSAO    // tempo p/ concluir a mudana em curso              [ Valor: Integer  ] 
	}	
		

}